@@ -9,7 +9,7 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: DocCommand.class.php 68 2006-04-01 14:27:55Z sakamoto $
+ * $Id: DocCommand.class.php 77 2006-04-09 15:57:21Z sakamoto $
  */
 
 /**
@@ -772,6 +772,42 @@ class AutoSOAP_Anno_RestrictionNameCmd implements AutoSOAP_Anno_Command {
     } 
 } 
 
+/**
+ * V^ƔhԂ
+ * array(
+ *     => ^,
+ *       E
+ *       E
+ *       E
+ *   )
+ *   : 
+ * 
+ * @package jp.servlet.AutoSOAP.Anno
+ * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
+ * @commandcode restriction_type
+ * @format ^ 
+ */
+class AutoSOAP_Anno_RestrictionTypeCmd implements AutoSOAP_Anno_Command {
+    private $result = null;
+    public function getCode()
+    {
+        return 'restriction_type';
+    } 
+    public function getResult()
+    {
+        return $this->result;
+    } 
+    public function execute($value)
+    {
+        $matchs = array();
+        if (preg_match("/^(\S+)\s+(\S+)/i", $value, $matchs)) {
+            $this->result[$matchs[2]] = $matchs[1];
+        } else {
+            trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
+        } 
+    } 
+} 
+
 /**
  * Ԃ
  * array(
@@ -884,4 +920,35 @@ class AutoSOAP_Anno_AccessCmd implements AutoSOAP_Anno_Command {
     } 
 } 
 
+/**
+ * ؎̃G[bZ[WԂ
+ *   : s
+ * 
+ * @package jp.servlet.AutoSOAP.Anno
+ * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
+ * @commandcode validate_error
+ * @format G[bZ[W
+ */
+class AutoSOAP_Anno_ValidateErrorCmd implements AutoSOAP_Anno_Command {
+    private $result = null;
+    public function getCode()
+    {
+        return 'validate_error';
+    } 
+    public function getResult()
+    {
+        return $this->result;
+    } 
+    public function execute($value)
+    {
+        $matchs = array();
+        if (!is_null($this->result)) {
+            trigger_error('It has already been set.(' . __CLASS__ . ')', E_USER_WARNING);
+        } else if (preg_match("/(?:\S.*)/i", $value, $matchs)) {
+            $this->result = $matchs[0];
+        } else {
+            trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
+        } 
+    } 
+} 
 ?>
\ No newline at end of file
